# a GNUPLOT script
#
# to produce output in the form of *.eps figure:
# 1. run gnuplot in the directory of this file
# 2. and type: load 'this_file'
# =================================================================================

set term post enh eps color solid "Helvetica" 20
set output "heat_capacity_multi.eps"

set key noauto

set size 1,1
set origin 0,0
# set title "MC:Wolff for a generalised XY model at j=0.08"
set xtics 0,0.05 font "Helvetica,20" textcolor lt 0   # tics of the major plot
set ytics 0,0.5 font "Helvetica,20" textcolor lt 0
set xrange [0.0:0.25]
set yrange [0.0:4.5] 
set key right top box lc 0 lt 3 lw 3                    # legend position

set multiplot                            # This will followed by two plots

set size 1,1                             # The first one (host plot)
set origin 0,0                           # origin of the major plot
set xlabel "T / J"                       # x-axis label
set ylabel "heat capacity / 1"           # y-axis label
plot "data/heat_capacity_j0.08_N8.txt" using 1:2:3 title 'N=8' with errorbars,  \
    "data/heat_capacity_j0.08_N16.txt" using 1:2:3 title 'N=16' with errorbars,  \
    "data/heat_capacity_j0.08_N32.txt" using 1:2:3 title 'N=32' with errorbars,  \
    "data/heat_capacity_j0.08_N64.txt" using 1:2:3 title 'N=64' with errorbars,  \
    "data/heat_capacity_j0.08_N128.txt" using 1:2:3 title 'N=128' with errorbars,  \
    "data/heat_capacity_j0.08_N256.txt" using 1:2:3 title 'N=256' with errorbars


set size 0.5,0.6        # The second one (inset)
set origin 0.1,0.3
unset title
unset xlabel
unset ylabel
set xtics 0,0.0025 font "Helvetica,16" textcolor lt 3
set ytics 0.5 font "Helvetica,16" textcolor lt 3
set nokey
# set xtics nomirror 0.04,0.04,0.16 font "Helvetica,16" textcolor lt 3
# set ytics nomirror -1,0.5,0.5 font "Helvetica,16" textcolor lt 3
set xrange [0.17:0.18]
set yrange [2.0:4.5]
plot "data/heat_capacity_j0.08_N8.txt" using 1:2:3  with errorbars,  \
    "data/heat_capacity_j0.08_N16.txt" using 1:2:3  with errorbars,   \
    "data/heat_capacity_j0.08_N32.txt" using 1:2:3  with errorbars,   \
    "data/heat_capacity_j0.08_N64.txt" using 1:2:3  with errorbars,   \
    "data/heat_capacity_j0.08_N128.txt" using 1:2:3  with errorbars,  \
    "data/heat_capacity_j0.08_N256.txt" using 1:2:3 with errorbars

unset multiplot
