# a GNUPLOT script
#
# to produce output in the form of *.eps figure:
# 1. run gnuplot in the directory of this file
# 2. and type: load 'this_file'
# =================================================================================

set term post enh eps color solid "Helvetica" 20
set output "helicity_multi.eps"

set key noauto

set size 1,1
set origin 0,0
# set title "MC:Wolff for a generalised XY model at j=0.08"
set xtics 0,0.05 font "Helvetica,20" textcolor lt 0   # tics of the major plot
set ytics 0,0.2 font "Helvetica,20" textcolor lt 0
set xrange [0.0:0.25]
set yrange [0.0:1.0] 
set key at 0.22,0.36 box lc 0 lt 3 lw 3                    # legend position

set multiplot                            # This will followed by two plots

set size 1,1                             # The first one (host plot)
set origin 0,0                           # origin of the major plot
set xlabel "T / J"                       # x-axis label
set ylabel "helicity modulus / J"        # y-axis label
plot "data/helicity_j0.08_N8.txt" using 1:2:3 title 'N=8' with errorbars,  \
    "data/helicity_j0.08_N16.txt" using 1:2:3 title 'N=16' with errorbars,  \
    "data/helicity_j0.08_N32.txt" using 1:2:3 title 'N=32' with errorbars,  \
    "data/helicity_j0.08_N64.txt" using 1:2:3 title 'N=64' with errorbars,  \
    "data/helicity_j0.08_N128.txt" using 1:2:3 title 'N=128' with errorbars,  \
    "data/helicity_j0.08_N256.txt" using 1:2:3 title 'N=256' with errorbars,  \
    8*x/pi with lines


set size 0.5,0.5        # The second one (inset)
set origin 0.14,0.20
clear                   # should clear background for the 2nd plot (=inset)
unset title
unset xlabel
unset ylabel
set xtics 0,0.01 font "Helvetica,16" textcolor lt 3
set ytics 0.1 font "Helvetica,16" textcolor lt 3
set nokey
# set xtics nomirror 0.04,0.04,0.16 font "Helvetica,16" textcolor lt 3
# set ytics nomirror -1,0.5,0.5 font "Helvetica,16" textcolor lt 3
set xrange [0.18:0.23]
set yrange [0.5:0.8]
plot "data/helicity_j0.08_N8.txt" using 1:2:3  with errorbars,  \
    "data/helicity_j0.08_N16.txt" using 1:2:3  with errorbars,   \
    "data/helicity_j0.08_N32.txt" using 1:2:3  with errorbars,   \
    "data/helicity_j0.08_N64.txt" using 1:2:3  with errorbars,   \
    "data/helicity_j0.08_N128.txt" using 1:2:3  with errorbars,  \
    "data/helicity_j0.08_N256.txt" using 1:2:3 with errorbars,  \
    8*x/pi with lines

unset multiplot
reset
